aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorWojtek Kosior <kwojtus@protonmail.com>2020-01-13 14:37:02 +0100
committerWojtek Kosior <kwojtus@protonmail.com>2020-01-13 14:37:02 +0100
commitde8804d159f684a5a41692951141fb62db9534d0 (patch)
treebdb4b94debd85a3ab9b24655974c23540ce15929 /src
parentb90be038ad473aa3e1d662d21a94dfca1eb6df78 (diff)
downloadrpi-MMU-example-de8804d159f684a5a41692951141fb62db9534d0.tar.gz
rpi-MMU-example-de8804d159f684a5a41692951141fb62db9534d0.zip
rename PL_0_test.img to PL0_test.img
Diffstat (limited to 'src')
-rw-r--r--src/arm/PL1/kernel/demo_functionality.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/arm/PL1/kernel/demo_functionality.c b/src/arm/PL1/kernel/demo_functionality.c
index 217a858..98f9784 100644
--- a/src/arm/PL1/kernel/demo_functionality.c
+++ b/src/arm/PL1/kernel/demo_functionality.c
@@ -67,13 +67,13 @@ extern char
void __attribute__((noreturn)) demo_setup_PL0(void)
{
- // find PL_0_test.img im ramfs
- struct ramfile PL_0_test_img;
+ // find PL0_test.img im ramfs
+ struct ramfile PL0_test_img;
- if (find_file(&_binary_ramfs_img_start, "PL_0_test.img",
- &PL_0_test_img))
+ if (find_file(&_binary_ramfs_img_start, "PL0_test.img",
+ &PL0_test_img))
{
- puts("PL_0_test.img not found :(");
+ puts("PL0_test.img not found :(");
asm volatile ("wfi");
}
@@ -110,7 +110,7 @@ void __attribute__((noreturn)) demo_setup_PL0(void)
// now paste a userspace program to that section
memcpy((void*) VIRTUAL_PL0_MEMORY_START,
- PL_0_test_img.file_contents, PL_0_test_img.file_size);
+ PL0_test_img.file_contents, PL0_test_img.file_size);
puts("copied PL0 code to it's section");